# coding: utf-8

"""
    wd-domain-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wd_domain_service.configuration import Configuration


class PumpInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'muid': 'str',
        'tenant_id': 'str',
        'show_name': 'str',
        'item_type': 'str',
        'device_indicator_infos': 'list[DeviceIndicatorInfo]'
    }

    attribute_map = {
        'id': 'id',
        'muid': 'muid',
        'tenant_id': 'tenantId',
        'show_name': 'showName',
        'item_type': 'itemType',
        'device_indicator_infos': 'deviceIndicatorInfos'
    }

    def __init__(self, id=None, muid=None, tenant_id=None, show_name=None, item_type=None, device_indicator_infos=None, local_vars_configuration=None):  # noqa: E501
        """PumpInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._muid = None
        self._tenant_id = None
        self._show_name = None
        self._item_type = None
        self._device_indicator_infos = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.muid = muid
        if tenant_id is not None:
            self.tenant_id = tenant_id
        self.show_name = show_name
        self.item_type = item_type
        self.device_indicator_infos = device_indicator_infos

    @property
    def id(self):
        """Gets the id of this PumpInfo.  # noqa: E501

        数据Id  # noqa: E501

        :return: The id of this PumpInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PumpInfo.

        数据Id  # noqa: E501

        :param id: The id of this PumpInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def muid(self):
        """Gets the muid of this PumpInfo.  # noqa: E501

        模型中的Id  # noqa: E501

        :return: The muid of this PumpInfo.  # noqa: E501
        :rtype: str
        """
        return self._muid

    @muid.setter
    def muid(self, muid):
        """Sets the muid of this PumpInfo.

        模型中的Id  # noqa: E501

        :param muid: The muid of this PumpInfo.  # noqa: E501
        :type: str
        """

        self._muid = muid

    @property
    def tenant_id(self):
        """Gets the tenant_id of this PumpInfo.  # noqa: E501

        租户信息  # noqa: E501

        :return: The tenant_id of this PumpInfo.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this PumpInfo.

        租户信息  # noqa: E501

        :param tenant_id: The tenant_id of this PumpInfo.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    @property
    def show_name(self):
        """Gets the show_name of this PumpInfo.  # noqa: E501

        展示名  # noqa: E501

        :return: The show_name of this PumpInfo.  # noqa: E501
        :rtype: str
        """
        return self._show_name

    @show_name.setter
    def show_name(self, show_name):
        """Sets the show_name of this PumpInfo.

        展示名  # noqa: E501

        :param show_name: The show_name of this PumpInfo.  # noqa: E501
        :type: str
        """

        self._show_name = show_name

    @property
    def item_type(self):
        """Gets the item_type of this PumpInfo.  # noqa: E501

        数据项类型  # noqa: E501

        :return: The item_type of this PumpInfo.  # noqa: E501
        :rtype: str
        """
        return self._item_type

    @item_type.setter
    def item_type(self, item_type):
        """Sets the item_type of this PumpInfo.

        数据项类型  # noqa: E501

        :param item_type: The item_type of this PumpInfo.  # noqa: E501
        :type: str
        """

        self._item_type = item_type

    @property
    def device_indicator_infos(self):
        """Gets the device_indicator_infos of this PumpInfo.  # noqa: E501

        边界点位对应的测点指标信息  # noqa: E501

        :return: The device_indicator_infos of this PumpInfo.  # noqa: E501
        :rtype: list[DeviceIndicatorInfo]
        """
        return self._device_indicator_infos

    @device_indicator_infos.setter
    def device_indicator_infos(self, device_indicator_infos):
        """Sets the device_indicator_infos of this PumpInfo.

        边界点位对应的测点指标信息  # noqa: E501

        :param device_indicator_infos: The device_indicator_infos of this PumpInfo.  # noqa: E501
        :type: list[DeviceIndicatorInfo]
        """

        self._device_indicator_infos = device_indicator_infos

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PumpInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PumpInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    wd-domain-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wd_domain_service.configuration import Configuration


class AddPipeRiskWeightInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'weight_factor_name': 'str',
        'weight': 'float',
        'pipe_field': 'str'
    }

    attribute_map = {
        'weight_factor_name': 'weightFactorName',
        'weight': 'weight',
        'pipe_field': 'pipeField'
    }

    def __init__(self, weight_factor_name=None, weight=None, pipe_field=None, local_vars_configuration=None):  # noqa: E501
        """AddPipeRiskWeightInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._weight_factor_name = None
        self._weight = None
        self._pipe_field = None
        self.discriminator = None

        self.weight_factor_name = weight_factor_name
        if weight is not None:
            self.weight = weight
        self.pipe_field = pipe_field

    @property
    def weight_factor_name(self):
        """Gets the weight_factor_name of this AddPipeRiskWeightInput.  # noqa: E501

        参数名  # noqa: E501

        :return: The weight_factor_name of this AddPipeRiskWeightInput.  # noqa: E501
        :rtype: str
        """
        return self._weight_factor_name

    @weight_factor_name.setter
    def weight_factor_name(self, weight_factor_name):
        """Sets the weight_factor_name of this AddPipeRiskWeightInput.

        参数名  # noqa: E501

        :param weight_factor_name: The weight_factor_name of this AddPipeRiskWeightInput.  # noqa: E501
        :type: str
        """

        self._weight_factor_name = weight_factor_name

    @property
    def weight(self):
        """Gets the weight of this AddPipeRiskWeightInput.  # noqa: E501

        权重  # noqa: E501

        :return: The weight of this AddPipeRiskWeightInput.  # noqa: E501
        :rtype: float
        """
        return self._weight

    @weight.setter
    def weight(self, weight):
        """Sets the weight of this AddPipeRiskWeightInput.

        权重  # noqa: E501

        :param weight: The weight of this AddPipeRiskWeightInput.  # noqa: E501
        :type: float
        """

        self._weight = weight

    @property
    def pipe_field(self):
        """Gets the pipe_field of this AddPipeRiskWeightInput.  # noqa: E501

        对应管道属性表的字段  # noqa: E501

        :return: The pipe_field of this AddPipeRiskWeightInput.  # noqa: E501
        :rtype: str
        """
        return self._pipe_field

    @pipe_field.setter
    def pipe_field(self, pipe_field):
        """Sets the pipe_field of this AddPipeRiskWeightInput.

        对应管道属性表的字段  # noqa: E501

        :param pipe_field: The pipe_field of this AddPipeRiskWeightInput.  # noqa: E501
        :type: str
        """

        self._pipe_field = pipe_field

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddPipeRiskWeightInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AddPipeRiskWeightInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    IoT服务

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_iot_service.configuration import Configuration


class QueryOpcUaPubSubInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'opc_flag': 'str',
        'sub_key': 'str',
        'node': 'str',
        'notify_pattern': 'str'
    }

    attribute_map = {
        'opc_flag': 'opcFlag',
        'sub_key': 'subKey',
        'node': 'node',
        'notify_pattern': 'notifyPattern'
    }

    def __init__(self, opc_flag=None, sub_key=None, node=None, notify_pattern=None, local_vars_configuration=None):  # noqa: E501
        """QueryOpcUaPubSubInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._opc_flag = None
        self._sub_key = None
        self._node = None
        self._notify_pattern = None
        self.discriminator = None

        self.opc_flag = opc_flag
        self.sub_key = sub_key
        self.node = node
        self.notify_pattern = notify_pattern

    @property
    def opc_flag(self):
        """Gets the opc_flag of this QueryOpcUaPubSubInput.  # noqa: E501

        标识,OpcUaConfig表的OpcFlag mark,OpcFlag of OpcUaConfig table  # noqa: E501

        :return: The opc_flag of this QueryOpcUaPubSubInput.  # noqa: E501
        :rtype: str
        """
        return self._opc_flag

    @opc_flag.setter
    def opc_flag(self, opc_flag):
        """Sets the opc_flag of this QueryOpcUaPubSubInput.

        标识,OpcUaConfig表的OpcFlag mark,OpcFlag of OpcUaConfig table  # noqa: E501

        :param opc_flag: The opc_flag of this QueryOpcUaPubSubInput.  # noqa: E501
        :type: str
        """

        self._opc_flag = opc_flag

    @property
    def sub_key(self):
        """Gets the sub_key of this QueryOpcUaPubSubInput.  # noqa: E501

        订阅回调标识Key subscription callback ID Key  # noqa: E501

        :return: The sub_key of this QueryOpcUaPubSubInput.  # noqa: E501
        :rtype: str
        """
        return self._sub_key

    @sub_key.setter
    def sub_key(self, sub_key):
        """Sets the sub_key of this QueryOpcUaPubSubInput.

        订阅回调标识Key subscription callback ID Key  # noqa: E501

        :param sub_key: The sub_key of this QueryOpcUaPubSubInput.  # noqa: E501
        :type: str
        """

        self._sub_key = sub_key

    @property
    def node(self):
        """Gets the node of this QueryOpcUaPubSubInput.  # noqa: E501

        要订阅的节点名 node name to subscribe to  # noqa: E501

        :return: The node of this QueryOpcUaPubSubInput.  # noqa: E501
        :rtype: str
        """
        return self._node

    @node.setter
    def node(self, node):
        """Sets the node of this QueryOpcUaPubSubInput.

        要订阅的节点名 node name to subscribe to  # noqa: E501

        :param node: The node of this QueryOpcUaPubSubInput.  # noqa: E501
        :type: str
        """

        self._node = node

    @property
    def notify_pattern(self):
        """Gets the notify_pattern of this QueryOpcUaPubSubInput.  # noqa: E501

        通知模式：kafka,notify,rabitmq notification mode: kafka,notify,rabitmq, etc.  # noqa: E501

        :return: The notify_pattern of this QueryOpcUaPubSubInput.  # noqa: E501
        :rtype: str
        """
        return self._notify_pattern

    @notify_pattern.setter
    def notify_pattern(self, notify_pattern):
        """Sets the notify_pattern of this QueryOpcUaPubSubInput.

        通知模式：kafka,notify,rabitmq notification mode: kafka,notify,rabitmq, etc.  # noqa: E501

        :param notify_pattern: The notify_pattern of this QueryOpcUaPubSubInput.  # noqa: E501
        :type: str
        """

        self._notify_pattern = notify_pattern

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QueryOpcUaPubSubInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, QueryOpcUaPubSubInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    wd-domain-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wd_domain_service.configuration import Configuration


class AccuracyConfigDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'type_name': 'str',
        'threshold': 'float',
        'unit': 'str',
        'description': 'str',
        'remark': 'str',
        'id': 'str'
    }

    attribute_map = {
        'type': 'type',
        'type_name': 'typeName',
        'threshold': 'threshold',
        'unit': 'unit',
        'description': 'description',
        'remark': 'remark',
        'id': 'id'
    }

    def __init__(self, type=None, type_name=None, threshold=None, unit=None, description=None, remark=None, id=None, local_vars_configuration=None):  # noqa: E501
        """AccuracyConfigDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._type_name = None
        self._threshold = None
        self._unit = None
        self._description = None
        self._remark = None
        self._id = None
        self.discriminator = None

        self.type = type
        self.type_name = type_name
        if threshold is not None:
            self.threshold = threshold
        self.unit = unit
        self.description = description
        self.remark = remark
        if id is not None:
            self.id = id

    @property
    def type(self):
        """Gets the type of this AccuracyConfigDto.  # noqa: E501

        精度类型  # noqa: E501

        :return: The type of this AccuracyConfigDto.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this AccuracyConfigDto.

        精度类型  # noqa: E501

        :param type: The type of this AccuracyConfigDto.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def type_name(self):
        """Gets the type_name of this AccuracyConfigDto.  # noqa: E501

        精度类型-中文显示  # noqa: E501

        :return: The type_name of this AccuracyConfigDto.  # noqa: E501
        :rtype: str
        """
        return self._type_name

    @type_name.setter
    def type_name(self, type_name):
        """Sets the type_name of this AccuracyConfigDto.

        精度类型-中文显示  # noqa: E501

        :param type_name: The type_name of this AccuracyConfigDto.  # noqa: E501
        :type: str
        """

        self._type_name = type_name

    @property
    def threshold(self):
        """Gets the threshold of this AccuracyConfigDto.  # noqa: E501

        阈值  # noqa: E501

        :return: The threshold of this AccuracyConfigDto.  # noqa: E501
        :rtype: float
        """
        return self._threshold

    @threshold.setter
    def threshold(self, threshold):
        """Sets the threshold of this AccuracyConfigDto.

        阈值  # noqa: E501

        :param threshold: The threshold of this AccuracyConfigDto.  # noqa: E501
        :type: float
        """

        self._threshold = threshold

    @property
    def unit(self):
        """Gets the unit of this AccuracyConfigDto.  # noqa: E501

        单位  # noqa: E501

        :return: The unit of this AccuracyConfigDto.  # noqa: E501
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """Sets the unit of this AccuracyConfigDto.

        单位  # noqa: E501

        :param unit: The unit of this AccuracyConfigDto.  # noqa: E501
        :type: str
        """

        self._unit = unit

    @property
    def description(self):
        """Gets the description of this AccuracyConfigDto.  # noqa: E501

        描述  # noqa: E501

        :return: The description of this AccuracyConfigDto.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this AccuracyConfigDto.

        描述  # noqa: E501

        :param description: The description of this AccuracyConfigDto.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def remark(self):
        """Gets the remark of this AccuracyConfigDto.  # noqa: E501

        备注  # noqa: E501

        :return: The remark of this AccuracyConfigDto.  # noqa: E501
        :rtype: str
        """
        return self._remark

    @remark.setter
    def remark(self, remark):
        """Sets the remark of this AccuracyConfigDto.

        备注  # noqa: E501

        :param remark: The remark of this AccuracyConfigDto.  # noqa: E501
        :type: str
        """

        self._remark = remark

    @property
    def id(self):
        """Gets the id of this AccuracyConfigDto.  # noqa: E501


        :return: The id of this AccuracyConfigDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AccuracyConfigDto.


        :param id: The id of this AccuracyConfigDto.  # noqa: E501
        :type: str
        """

        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccuracyConfigDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AccuracyConfigDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    identity-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_identity_service.configuration import Configuration


class ConfigItem(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'config_code': 'int',
        'config_name': 'str',
        'config_desc': 'str',
        'selected': 'bool'
    }

    attribute_map = {
        'config_code': 'configCode',
        'config_name': 'configName',
        'config_desc': 'configDesc',
        'selected': 'selected'
    }

    def __init__(self, config_code=None, config_name=None, config_desc=None, selected=None, local_vars_configuration=None):  # noqa: E501
        """ConfigItem - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._config_code = None
        self._config_name = None
        self._config_desc = None
        self._selected = None
        self.discriminator = None

        if config_code is not None:
            self.config_code = config_code
        self.config_name = config_name
        self.config_desc = config_desc
        if selected is not None:
            self.selected = selected

    @property
    def config_code(self):
        """Gets the config_code of this ConfigItem.  # noqa: E501

        配置项代码 config code  # noqa: E501

        :return: The config_code of this ConfigItem.  # noqa: E501
        :rtype: int
        """
        return self._config_code

    @config_code.setter
    def config_code(self, config_code):
        """Sets the config_code of this ConfigItem.

        配置项代码 config code  # noqa: E501

        :param config_code: The config_code of this ConfigItem.  # noqa: E501
        :type: int
        """

        self._config_code = config_code

    @property
    def config_name(self):
        """Gets the config_name of this ConfigItem.  # noqa: E501

        配置项名称 config name  # noqa: E501

        :return: The config_name of this ConfigItem.  # noqa: E501
        :rtype: str
        """
        return self._config_name

    @config_name.setter
    def config_name(self, config_name):
        """Sets the config_name of this ConfigItem.

        配置项名称 config name  # noqa: E501

        :param config_name: The config_name of this ConfigItem.  # noqa: E501
        :type: str
        """

        self._config_name = config_name

    @property
    def config_desc(self):
        """Gets the config_desc of this ConfigItem.  # noqa: E501

        配置项描述 config description  # noqa: E501

        :return: The config_desc of this ConfigItem.  # noqa: E501
        :rtype: str
        """
        return self._config_desc

    @config_desc.setter
    def config_desc(self, config_desc):
        """Sets the config_desc of this ConfigItem.

        配置项描述 config description  # noqa: E501

        :param config_desc: The config_desc of this ConfigItem.  # noqa: E501
        :type: str
        """

        self._config_desc = config_desc

    @property
    def selected(self):
        """Gets the selected of this ConfigItem.  # noqa: E501

        是否被选中 if selected  # noqa: E501

        :return: The selected of this ConfigItem.  # noqa: E501
        :rtype: bool
        """
        return self._selected

    @selected.setter
    def selected(self, selected):
        """Sets the selected of this ConfigItem.

        是否被选中 if selected  # noqa: E501

        :param selected: The selected of this ConfigItem.  # noqa: E501
        :type: bool
        """

        self._selected = selected

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConfigItem):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ConfigItem):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    wwtp-paas-infrastructure-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wwtp_infrastructure_service.configuration import Configuration


class GetOutputCostPerFlowsInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'node_codes': 'list[str]',
        's_time': 'datetime',
        'e_time': 'datetime'
    }

    attribute_map = {
        'node_codes': 'nodeCodes',
        's_time': 'sTime',
        'e_time': 'eTime'
    }

    def __init__(self, node_codes=None, s_time=None, e_time=None, local_vars_configuration=None):  # noqa: E501
        """GetOutputCostPerFlowsInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._node_codes = None
        self._s_time = None
        self._e_time = None
        self.discriminator = None

        self.node_codes = node_codes
        self.s_time = s_time
        self.e_time = e_time

    @property
    def node_codes(self):
        """Gets the node_codes of this GetOutputCostPerFlowsInput.  # noqa: E501

        模型点位编码 model node codes  # noqa: E501

        :return: The node_codes of this GetOutputCostPerFlowsInput.  # noqa: E501
        :rtype: list[str]
        """
        return self._node_codes

    @node_codes.setter
    def node_codes(self, node_codes):
        """Sets the node_codes of this GetOutputCostPerFlowsInput.

        模型点位编码 model node codes  # noqa: E501

        :param node_codes: The node_codes of this GetOutputCostPerFlowsInput.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and node_codes is None:  # noqa: E501
            raise ValueError("Invalid value for `node_codes`, must not be `None`")  # noqa: E501

        self._node_codes = node_codes

    @property
    def s_time(self):
        """Gets the s_time of this GetOutputCostPerFlowsInput.  # noqa: E501

        开始时间 start time  # noqa: E501

        :return: The s_time of this GetOutputCostPerFlowsInput.  # noqa: E501
        :rtype: datetime
        """
        return self._s_time

    @s_time.setter
    def s_time(self, s_time):
        """Sets the s_time of this GetOutputCostPerFlowsInput.

        开始时间 start time  # noqa: E501

        :param s_time: The s_time of this GetOutputCostPerFlowsInput.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and s_time is None:  # noqa: E501
            raise ValueError("Invalid value for `s_time`, must not be `None`")  # noqa: E501

        self._s_time = s_time

    @property
    def e_time(self):
        """Gets the e_time of this GetOutputCostPerFlowsInput.  # noqa: E501

        结束时间 end time  # noqa: E501

        :return: The e_time of this GetOutputCostPerFlowsInput.  # noqa: E501
        :rtype: datetime
        """
        return self._e_time

    @e_time.setter
    def e_time(self, e_time):
        """Sets the e_time of this GetOutputCostPerFlowsInput.

        结束时间 end time  # noqa: E501

        :param e_time: The e_time of this GetOutputCostPerFlowsInput.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and e_time is None:  # noqa: E501
            raise ValueError("Invalid value for `e_time`, must not be `None`")  # noqa: E501

        self._e_time = e_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetOutputCostPerFlowsInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GetOutputCostPerFlowsInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    identity-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from dhicn_identity_service.api_client import ApiClient
from dhicn_identity_service.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class OrganizationManangerApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_v1_organization_add_post(self, **kwargs):  # noqa: E501
        """增加组织机构 | add organization  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_organization_add_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddOrganizationInput add_organization_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: OrganizationEntity
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_organization_add_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_organization_add_post_with_http_info(self, **kwargs):  # noqa: E501
        """增加组织机构 | add organization  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_organization_add_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddOrganizationInput add_organization_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(OrganizationEntity, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_organization_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_organization_add_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_organization_input' in local_var_params:
            body_params = local_var_params['add_organization_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/organization/add', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OrganizationEntity',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_organization_delete_post(self, **kwargs):  # noqa: E501
        """删除组织架构 | delete organization  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_organization_delete_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param KeysInput keys_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_organization_delete_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_organization_delete_post_with_http_info(self, **kwargs):  # noqa: E501
        """删除组织架构 | delete organization  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_organization_delete_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param KeysInput keys_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'keys_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_organization_delete_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'keys_input' in local_var_params:
            body_params = local_var_params['keys_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/organization/delete', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_organization_tree_get(self, **kwargs):  # noqa: E501
        """查询组织架构树 | query organization tree  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_organization_tree_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[QueryOrganizationOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_organization_tree_get_with_http_info(**kwargs)  # noqa: E501

    def api_v1_organization_tree_get_with_http_info(self, **kwargs):  # noqa: E501
        """查询组织架构树 | query organization tree  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_organization_tree_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[QueryOrganizationOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_organization_tree_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/organization/tree', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[QueryOrganizationOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_organization_update_post(self, **kwargs):  # noqa: E501
        """修改组织架构 | update organization  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_organization_update_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateOrganizationInput update_organization_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[OrganizationEntity]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_organization_update_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_organization_update_post_with_http_info(self, **kwargs):  # noqa: E501
        """修改组织架构 | update organization  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_organization_update_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateOrganizationInput update_organization_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[OrganizationEntity], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'update_organization_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_organization_update_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_organization_input' in local_var_params:
            body_params = local_var_params['update_organization_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/organization/update', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[OrganizationEntity]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_organization_user_relevance_add_post(self, **kwargs):  # noqa: E501
        """增加组织架构-用户关系 | bind organization and user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_organization_user_relevance_add_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[AddOrganizationUserRelInput] add_organization_user_rel_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_organization_user_relevance_add_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_organization_user_relevance_add_post_with_http_info(self, **kwargs):  # noqa: E501
        """增加组织架构-用户关系 | bind organization and user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_organization_user_relevance_add_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[AddOrganizationUserRelInput] add_organization_user_rel_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_organization_user_rel_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_organization_user_relevance_add_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_organization_user_rel_input' in local_var_params:
            body_params = local_var_params['add_organization_user_rel_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/organization-user-relevance/add', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_organization_user_relevance_delete_post(self, **kwargs):  # noqa: E501
        """删除组织架构用户关联 | delete organization with user relevance  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_organization_user_relevance_delete_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param DeleteOrganizationUserRelInput delete_organization_user_rel_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_organization_user_relevance_delete_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_organization_user_relevance_delete_post_with_http_info(self, **kwargs):  # noqa: E501
        """删除组织架构用户关联 | delete organization with user relevance  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_organization_user_relevance_delete_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param DeleteOrganizationUserRelInput delete_organization_user_rel_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'delete_organization_user_rel_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_organization_user_relevance_delete_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'delete_organization_user_rel_input' in local_var_params:
            body_params = local_var_params['delete_organization_user_rel_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/organization-user-relevance/delete', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_organization_with_user_info_tree_post(self, **kwargs):  # noqa: E501
        """查询组织架构树及所有人员，如果传入的组织架构ID为空，则返回所有组织架构 | query organization with user's detail information,if organization's id is null,we will return all organizations  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_organization_with_user_info_tree_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param QueryOrganizationWithUserInfoInput query_organization_with_user_info_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[OrganizationWithUserInfoOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_organization_with_user_info_tree_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_organization_with_user_info_tree_post_with_http_info(self, **kwargs):  # noqa: E501
        """查询组织架构树及所有人员，如果传入的组织架构ID为空，则返回所有组织架构 | query organization with user's detail information,if organization's id is null,we will return all organizations  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_organization_with_user_info_tree_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param QueryOrganizationWithUserInfoInput query_organization_with_user_info_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[OrganizationWithUserInfoOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'query_organization_with_user_info_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_organization_with_user_info_tree_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'query_organization_with_user_info_input' in local_var_params:
            body_params = local_var_params['query_organization_with_user_info_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/organization-with-user-info/tree', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[OrganizationWithUserInfoOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_user_details_query_by_keyword_post(self, **kwargs):  # noqa: E501
        """通过用户输入的关键字查询用户  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_user_details_query_by_keyword_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param QueryUserDetailsByUserInput query_user_details_by_user_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[QueryUserInformationOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_user_details_query_by_keyword_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_user_details_query_by_keyword_post_with_http_info(self, **kwargs):  # noqa: E501
        """通过用户输入的关键字查询用户  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_user_details_query_by_keyword_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param QueryUserDetailsByUserInput query_user_details_by_user_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[QueryUserInformationOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'query_user_details_by_user_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_user_details_query_by_keyword_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'query_user_details_by_user_input' in local_var_params:
            body_params = local_var_params['query_user_details_by_user_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/user-details/query-by-keyword', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[QueryUserInformationOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_user_details_query_by_user_id_post(self, **kwargs):  # noqa: E501
        """查询用户详细信息 | query user's detail information  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_user_details_query_by_user_id_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param QueryUserDetailsInput query_user_details_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[QueryUserInformationOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_user_details_query_by_user_id_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_user_details_query_by_user_id_post_with_http_info(self, **kwargs):  # noqa: E501
        """查询用户详细信息 | query user's detail information  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_user_details_query_by_user_id_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param QueryUserDetailsInput query_user_details_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[QueryUserInformationOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'query_user_details_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_user_details_query_by_user_id_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'query_user_details_input' in local_var_params:
            body_params = local_var_params['query_user_details_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/user-details/query-by-user-id', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[QueryUserInformationOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    wwtp-paas-main-bus-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wwtp_data_bus_service.configuration import Configuration


class ToxicAlarmsOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'location': 'str',
        'time': 'datetime',
        'toxic_level': 'int',
        'description': 'str'
    }

    attribute_map = {
        'location': 'location',
        'time': 'time',
        'toxic_level': 'toxicLevel',
        'description': 'description'
    }

    def __init__(self, location=None, time=None, toxic_level=None, description=None, local_vars_configuration=None):  # noqa: E501
        """ToxicAlarmsOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._location = None
        self._time = None
        self._toxic_level = None
        self._description = None
        self.discriminator = None

        self.location = location
        if time is not None:
            self.time = time
        if toxic_level is not None:
            self.toxic_level = toxic_level
        self.description = description

    @property
    def location(self):
        """Gets the location of this ToxicAlarmsOutput.  # noqa: E501

        毒性仪位置 toxicity meter location  # noqa: E501

        :return: The location of this ToxicAlarmsOutput.  # noqa: E501
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this ToxicAlarmsOutput.

        毒性仪位置 toxicity meter location  # noqa: E501

        :param location: The location of this ToxicAlarmsOutput.  # noqa: E501
        :type: str
        """

        self._location = location

    @property
    def time(self):
        """Gets the time of this ToxicAlarmsOutput.  # noqa: E501

        预警时刻 alarm time  # noqa: E501

        :return: The time of this ToxicAlarmsOutput.  # noqa: E501
        :rtype: datetime
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this ToxicAlarmsOutput.

        预警时刻 alarm time  # noqa: E501

        :param time: The time of this ToxicAlarmsOutput.  # noqa: E501
        :type: datetime
        """

        self._time = time

    @property
    def toxic_level(self):
        """Gets the toxic_level of this ToxicAlarmsOutput.  # noqa: E501

        毒性程度 toxicity level  # noqa: E501

        :return: The toxic_level of this ToxicAlarmsOutput.  # noqa: E501
        :rtype: int
        """
        return self._toxic_level

    @toxic_level.setter
    def toxic_level(self, toxic_level):
        """Sets the toxic_level of this ToxicAlarmsOutput.

        毒性程度 toxicity level  # noqa: E501

        :param toxic_level: The toxic_level of this ToxicAlarmsOutput.  # noqa: E501
        :type: int
        """
        allowed_values = [0, 1, 2]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and toxic_level not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `toxic_level` ({0}), must be one of {1}"  # noqa: E501
                .format(toxic_level, allowed_values)
            )

        self._toxic_level = toxic_level

    @property
    def description(self):
        """Gets the description of this ToxicAlarmsOutput.  # noqa: E501

        毒性程度描述 toxicity level description  # noqa: E501

        :return: The description of this ToxicAlarmsOutput.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ToxicAlarmsOutput.

        毒性程度描述 toxicity level description  # noqa: E501

        :param description: The description of this ToxicAlarmsOutput.  # noqa: E501
        :type: str
        """

        self._description = description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ToxicAlarmsOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ToxicAlarmsOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    wwtp-paas-main-bus-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wwtp_data_bus_service.configuration import Configuration


class ToxicityOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'col_codes': 'list[str]',
        'col_names': 'list[str]',
        'times': 'list[datetime]',
        'values': 'list[list[str]]'
    }

    attribute_map = {
        'col_codes': 'colCodes',
        'col_names': 'colNames',
        'times': 'times',
        'values': 'values'
    }

    def __init__(self, col_codes=None, col_names=None, times=None, values=None, local_vars_configuration=None):  # noqa: E501
        """ToxicityOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._col_codes = None
        self._col_names = None
        self._times = None
        self._values = None
        self.discriminator = None

        self.col_codes = col_codes
        self.col_names = col_names
        self.times = times
        self.values = values

    @property
    def col_codes(self):
        """Gets the col_codes of this ToxicityOutput.  # noqa: E501

        每一列对应的毒性指标 toxicity indicator of each column  # noqa: E501

        :return: The col_codes of this ToxicityOutput.  # noqa: E501
        :rtype: list[str]
        """
        return self._col_codes

    @col_codes.setter
    def col_codes(self, col_codes):
        """Sets the col_codes of this ToxicityOutput.

        每一列对应的毒性指标 toxicity indicator of each column  # noqa: E501

        :param col_codes: The col_codes of this ToxicityOutput.  # noqa: E501
        :type: list[str]
        """

        self._col_codes = col_codes

    @property
    def col_names(self):
        """Gets the col_names of this ToxicityOutput.  # noqa: E501

        每一列对应的指标名称 toxicity indicator name of each column  # noqa: E501

        :return: The col_names of this ToxicityOutput.  # noqa: E501
        :rtype: list[str]
        """
        return self._col_names

    @col_names.setter
    def col_names(self, col_names):
        """Sets the col_names of this ToxicityOutput.

        每一列对应的指标名称 toxicity indicator name of each column  # noqa: E501

        :param col_names: The col_names of this ToxicityOutput.  # noqa: E501
        :type: list[str]
        """

        self._col_names = col_names

    @property
    def times(self):
        """Gets the times of this ToxicityOutput.  # noqa: E501

        所有的时刻 all the time steps  # noqa: E501

        :return: The times of this ToxicityOutput.  # noqa: E501
        :rtype: list[datetime]
        """
        return self._times

    @times.setter
    def times(self, times):
        """Sets the times of this ToxicityOutput.

        所有的时刻 all the time steps  # noqa: E501

        :param times: The times of this ToxicityOutput.  # noqa: E501
        :type: list[datetime]
        """

        self._times = times

    @property
    def values(self):
        """Gets the values of this ToxicityOutput.  # noqa: E501

        每一个时刻，对应每一个指标的数值  value of each indicator of each time step  # noqa: E501

        :return: The values of this ToxicityOutput.  # noqa: E501
        :rtype: list[list[str]]
        """
        return self._values

    @values.setter
    def values(self, values):
        """Sets the values of this ToxicityOutput.

        每一个时刻，对应每一个指标的数值  value of each indicator of each time step  # noqa: E501

        :param values: The values of this ToxicityOutput.  # noqa: E501
        :type: list[list[str]]
        """

        self._values = values

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ToxicityOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ToxicityOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    IoT服务

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_iot_service.configuration import Configuration


class MockDeviceInfoInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'device_id': 'str',
        'indicator': 'str',
        'future_few_hours': 'int',
        'min_range': 'float',
        'max_range': 'float'
    }

    attribute_map = {
        'device_id': 'deviceId',
        'indicator': 'indicator',
        'future_few_hours': 'futureFewHours',
        'min_range': 'minRange',
        'max_range': 'maxRange'
    }

    def __init__(self, device_id=None, indicator=None, future_few_hours=None, min_range=None, max_range=None, local_vars_configuration=None):  # noqa: E501
        """MockDeviceInfoInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._device_id = None
        self._indicator = None
        self._future_few_hours = None
        self._min_range = None
        self._max_range = None
        self.discriminator = None

        self.device_id = device_id
        self.indicator = indicator
        if future_few_hours is not None:
            self.future_few_hours = future_few_hours
        self.min_range = min_range
        self.max_range = max_range

    @property
    def device_id(self):
        """Gets the device_id of this MockDeviceInfoInput.  # noqa: E501

        设备Id  # noqa: E501

        :return: The device_id of this MockDeviceInfoInput.  # noqa: E501
        :rtype: str
        """
        return self._device_id

    @device_id.setter
    def device_id(self, device_id):
        """Sets the device_id of this MockDeviceInfoInput.

        设备Id  # noqa: E501

        :param device_id: The device_id of this MockDeviceInfoInput.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and device_id is None:  # noqa: E501
            raise ValueError("Invalid value for `device_id`, must not be `None`")  # noqa: E501

        self._device_id = device_id

    @property
    def indicator(self):
        """Gets the indicator of this MockDeviceInfoInput.  # noqa: E501

        指标  # noqa: E501

        :return: The indicator of this MockDeviceInfoInput.  # noqa: E501
        :rtype: str
        """
        return self._indicator

    @indicator.setter
    def indicator(self, indicator):
        """Sets the indicator of this MockDeviceInfoInput.

        指标  # noqa: E501

        :param indicator: The indicator of this MockDeviceInfoInput.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and indicator is None:  # noqa: E501
            raise ValueError("Invalid value for `indicator`, must not be `None`")  # noqa: E501

        self._indicator = indicator

    @property
    def future_few_hours(self):
        """Gets the future_few_hours of this MockDeviceInfoInput.  # noqa: E501

        模拟未来多少小时的数据,默认为0代表:代表当前整点时刻,如6:代表未来6小时  # noqa: E501

        :return: The future_few_hours of this MockDeviceInfoInput.  # noqa: E501
        :rtype: int
        """
        return self._future_few_hours

    @future_few_hours.setter
    def future_few_hours(self, future_few_hours):
        """Sets the future_few_hours of this MockDeviceInfoInput.

        模拟未来多少小时的数据,默认为0代表:代表当前整点时刻,如6:代表未来6小时  # noqa: E501

        :param future_few_hours: The future_few_hours of this MockDeviceInfoInput.  # noqa: E501
        :type: int
        """

        self._future_few_hours = future_few_hours

    @property
    def min_range(self):
        """Gets the min_range of this MockDeviceInfoInput.  # noqa: E501

        Mock数据范围,最小值  # noqa: E501

        :return: The min_range of this MockDeviceInfoInput.  # noqa: E501
        :rtype: float
        """
        return self._min_range

    @min_range.setter
    def min_range(self, min_range):
        """Sets the min_range of this MockDeviceInfoInput.

        Mock数据范围,最小值  # noqa: E501

        :param min_range: The min_range of this MockDeviceInfoInput.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and min_range is None:  # noqa: E501
            raise ValueError("Invalid value for `min_range`, must not be `None`")  # noqa: E501

        self._min_range = min_range

    @property
    def max_range(self):
        """Gets the max_range of this MockDeviceInfoInput.  # noqa: E501

         /// <summary>  Mock数据范围,最大值  </summary>  # noqa: E501

        :return: The max_range of this MockDeviceInfoInput.  # noqa: E501
        :rtype: float
        """
        return self._max_range

    @max_range.setter
    def max_range(self, max_range):
        """Sets the max_range of this MockDeviceInfoInput.

         /// <summary>  Mock数据范围,最大值  </summary>  # noqa: E501

        :param max_range: The max_range of this MockDeviceInfoInput.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and max_range is None:  # noqa: E501
            raise ValueError("Invalid value for `max_range`, must not be `None`")  # noqa: E501

        self._max_range = max_range

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MockDeviceInfoInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MockDeviceInfoInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    result-analysis-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_result_analysis_service.configuration import Configuration


class ObjectId(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'timestamp': 'int',
        'machine': 'int',
        'pid': 'int',
        'increment': 'int',
        'creation_time': 'datetime'
    }

    attribute_map = {
        'timestamp': 'timestamp',
        'machine': 'machine',
        'pid': 'pid',
        'increment': 'increment',
        'creation_time': 'creationTime'
    }

    def __init__(self, timestamp=None, machine=None, pid=None, increment=None, creation_time=None, local_vars_configuration=None):  # noqa: E501
        """ObjectId - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._timestamp = None
        self._machine = None
        self._pid = None
        self._increment = None
        self._creation_time = None
        self.discriminator = None

        if timestamp is not None:
            self.timestamp = timestamp
        if machine is not None:
            self.machine = machine
        if pid is not None:
            self.pid = pid
        if increment is not None:
            self.increment = increment
        if creation_time is not None:
            self.creation_time = creation_time

    @property
    def timestamp(self):
        """Gets the timestamp of this ObjectId.  # noqa: E501


        :return: The timestamp of this ObjectId.  # noqa: E501
        :rtype: int
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this ObjectId.


        :param timestamp: The timestamp of this ObjectId.  # noqa: E501
        :type: int
        """

        self._timestamp = timestamp

    @property
    def machine(self):
        """Gets the machine of this ObjectId.  # noqa: E501


        :return: The machine of this ObjectId.  # noqa: E501
        :rtype: int
        """
        return self._machine

    @machine.setter
    def machine(self, machine):
        """Sets the machine of this ObjectId.


        :param machine: The machine of this ObjectId.  # noqa: E501
        :type: int
        """

        self._machine = machine

    @property
    def pid(self):
        """Gets the pid of this ObjectId.  # noqa: E501


        :return: The pid of this ObjectId.  # noqa: E501
        :rtype: int
        """
        return self._pid

    @pid.setter
    def pid(self, pid):
        """Sets the pid of this ObjectId.


        :param pid: The pid of this ObjectId.  # noqa: E501
        :type: int
        """

        self._pid = pid

    @property
    def increment(self):
        """Gets the increment of this ObjectId.  # noqa: E501


        :return: The increment of this ObjectId.  # noqa: E501
        :rtype: int
        """
        return self._increment

    @increment.setter
    def increment(self, increment):
        """Sets the increment of this ObjectId.


        :param increment: The increment of this ObjectId.  # noqa: E501
        :type: int
        """

        self._increment = increment

    @property
    def creation_time(self):
        """Gets the creation_time of this ObjectId.  # noqa: E501


        :return: The creation_time of this ObjectId.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_time

    @creation_time.setter
    def creation_time(self, creation_time):
        """Sets the creation_time of this ObjectId.


        :param creation_time: The creation_time of this ObjectId.  # noqa: E501
        :type: datetime
        """

        self._creation_time = creation_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ObjectId):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ObjectId):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    wd-domain-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wd_domain_service.configuration import Configuration


class GetAccuracyPara(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'scenario_id': 'str',
        'data_types': 'list[int]',
        'b_force_refresh_cache': 'bool'
    }

    attribute_map = {
        'scenario_id': 'scenarioId',
        'data_types': 'dataTypes',
        'b_force_refresh_cache': 'bForceRefreshCache'
    }

    def __init__(self, scenario_id=None, data_types=None, b_force_refresh_cache=None, local_vars_configuration=None):  # noqa: E501
        """GetAccuracyPara - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._scenario_id = None
        self._data_types = None
        self._b_force_refresh_cache = None
        self.discriminator = None

        if scenario_id is not None:
            self.scenario_id = scenario_id
        self.data_types = data_types
        if b_force_refresh_cache is not None:
            self.b_force_refresh_cache = b_force_refresh_cache

    @property
    def scenario_id(self):
        """Gets the scenario_id of this GetAccuracyPara.  # noqa: E501

        方案id  # noqa: E501

        :return: The scenario_id of this GetAccuracyPara.  # noqa: E501
        :rtype: str
        """
        return self._scenario_id

    @scenario_id.setter
    def scenario_id(self, scenario_id):
        """Sets the scenario_id of this GetAccuracyPara.

        方案id  # noqa: E501

        :param scenario_id: The scenario_id of this GetAccuracyPara.  # noqa: E501
        :type: str
        """

        self._scenario_id = scenario_id

    @property
    def data_types(self):
        """Gets the data_types of this GetAccuracyPara.  # noqa: E501

        数据类型  # noqa: E501

        :return: The data_types of this GetAccuracyPara.  # noqa: E501
        :rtype: list[int]
        """
        return self._data_types

    @data_types.setter
    def data_types(self, data_types):
        """Sets the data_types of this GetAccuracyPara.

        数据类型  # noqa: E501

        :param data_types: The data_types of this GetAccuracyPara.  # noqa: E501
        :type: list[int]
        """
        allowed_values = [None,0, 1, 2, 3, 4, 5, 6, 7, 8, 9]  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                not set(data_types).issubset(set(allowed_values))):  # noqa: E501
            raise ValueError(
                "Invalid values for `data_types` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(data_types) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._data_types = data_types

    @property
    def b_force_refresh_cache(self):
        """Gets the b_force_refresh_cache of this GetAccuracyPara.  # noqa: E501

        是否强制刷新缓存  # noqa: E501

        :return: The b_force_refresh_cache of this GetAccuracyPara.  # noqa: E501
        :rtype: bool
        """
        return self._b_force_refresh_cache

    @b_force_refresh_cache.setter
    def b_force_refresh_cache(self, b_force_refresh_cache):
        """Sets the b_force_refresh_cache of this GetAccuracyPara.

        是否强制刷新缓存  # noqa: E501

        :param b_force_refresh_cache: The b_force_refresh_cache of this GetAccuracyPara.  # noqa: E501
        :type: bool
        """

        self._b_force_refresh_cache = b_force_refresh_cache

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetAccuracyPara):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GetAccuracyPara):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    wwtp-paas-main-bus-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wwtp_data_bus_service.configuration import Configuration


class ModelOptimDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'control_items': 'list[ControlItem]',
        'precision_w_qs': 'list[PrecisionWq]'
    }

    attribute_map = {
        'control_items': 'controlItems',
        'precision_w_qs': 'precisionWQs'
    }

    def __init__(self, control_items=None, precision_w_qs=None, local_vars_configuration=None):  # noqa: E501
        """ModelOptimDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._control_items = None
        self._precision_w_qs = None
        self.discriminator = None

        self.control_items = control_items
        self.precision_w_qs = precision_w_qs

    @property
    def control_items(self):
        """Gets the control_items of this ModelOptimDto.  # noqa: E501

        控制项数据 control item data  # noqa: E501

        :return: The control_items of this ModelOptimDto.  # noqa: E501
        :rtype: list[ControlItem]
        """
        return self._control_items

    @control_items.setter
    def control_items(self, control_items):
        """Sets the control_items of this ModelOptimDto.

        控制项数据 control item data  # noqa: E501

        :param control_items: The control_items of this ModelOptimDto.  # noqa: E501
        :type: list[ControlItem]
        """

        self._control_items = control_items

    @property
    def precision_w_qs(self):
        """Gets the precision_w_qs of this ModelOptimDto.  # noqa: E501

        预测出水水质 effluent water quality data  # noqa: E501

        :return: The precision_w_qs of this ModelOptimDto.  # noqa: E501
        :rtype: list[PrecisionWq]
        """
        return self._precision_w_qs

    @precision_w_qs.setter
    def precision_w_qs(self, precision_w_qs):
        """Sets the precision_w_qs of this ModelOptimDto.

        预测出水水质 effluent water quality data  # noqa: E501

        :param precision_w_qs: The precision_w_qs of this ModelOptimDto.  # noqa: E501
        :type: list[PrecisionWq]
        """

        self._precision_w_qs = precision_w_qs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModelOptimDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ModelOptimDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    wwtp-paas-main-bus-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from dhicn_wwtp_data_bus_service.api_client import ApiClient
from dhicn_wwtp_data_bus_service.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class IntelligentBusConfigApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_intelligent_bus_config_add_intelligent_deni_display_configs_post(self, **kwargs):  # noqa: E501
        """添加智能加药展示配置信息 Add intelligent dosage page display config data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_intelligent_bus_config_add_intelligent_deni_display_configs_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[IntelligentDeniConfigInOut] intelligent_deni_config_in_out:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_intelligent_bus_config_add_intelligent_deni_display_configs_post_with_http_info(**kwargs)  # noqa: E501

    def api_intelligent_bus_config_add_intelligent_deni_display_configs_post_with_http_info(self, **kwargs):  # noqa: E501
        """添加智能加药展示配置信息 Add intelligent dosage page display config data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_intelligent_bus_config_add_intelligent_deni_display_configs_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[IntelligentDeniConfigInOut] intelligent_deni_config_in_out:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'intelligent_deni_config_in_out'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_intelligent_bus_config_add_intelligent_deni_display_configs_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'intelligent_deni_config_in_out' in local_var_params:
            body_params = local_var_params['intelligent_deni_config_in_out']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/IntelligentBusConfig/AddIntelligentDeniDisplayConfigs', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_intelligent_bus_config_delete_intelligent_deni_display_configs_post(self, **kwargs):  # noqa: E501
        """根据ID删除智能加药展示配置信息 Delete intelligent dosage page display config data by ids  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_intelligent_bus_config_delete_intelligent_deni_display_configs_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_intelligent_bus_config_delete_intelligent_deni_display_configs_post_with_http_info(**kwargs)  # noqa: E501

    def api_intelligent_bus_config_delete_intelligent_deni_display_configs_post_with_http_info(self, **kwargs):  # noqa: E501
        """根据ID删除智能加药展示配置信息 Delete intelligent dosage page display config data by ids  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_intelligent_bus_config_delete_intelligent_deni_display_configs_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'request_body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_intelligent_bus_config_delete_intelligent_deni_display_configs_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request_body' in local_var_params:
            body_params = local_var_params['request_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/IntelligentBusConfig/DeleteIntelligentDeniDisplayConfigs', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_intelligent_bus_config_get_all_intelligent_deni_display_configs_get(self, **kwargs):  # noqa: E501
        """获取所有的智能加药展示配置信息 Get all intelligent dosage page display config data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_intelligent_bus_config_get_all_intelligent_deni_display_configs_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[IntelligentDeniConfigInOut]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_intelligent_bus_config_get_all_intelligent_deni_display_configs_get_with_http_info(**kwargs)  # noqa: E501

    def api_intelligent_bus_config_get_all_intelligent_deni_display_configs_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取所有的智能加药展示配置信息 Get all intelligent dosage page display config data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_intelligent_bus_config_get_all_intelligent_deni_display_configs_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[IntelligentDeniConfigInOut], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_intelligent_bus_config_get_all_intelligent_deni_display_configs_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/IntelligentBusConfig/GetAllIntelligentDeniDisplayConfigs', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[IntelligentDeniConfigInOut]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_intelligent_bus_config_get_intelligent_deni_display_config_by_type_get(self, **kwargs):  # noqa: E501
        """通过展示类型枚举获取配置信息 Get intelligent dosage page display config data by display type  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_intelligent_bus_config_get_intelligent_deni_display_config_by_type_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int display_type: 展示类型枚举 display type
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[IntelligentDeniConfigInOut]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_intelligent_bus_config_get_intelligent_deni_display_config_by_type_get_with_http_info(**kwargs)  # noqa: E501

    def api_intelligent_bus_config_get_intelligent_deni_display_config_by_type_get_with_http_info(self, **kwargs):  # noqa: E501
        """通过展示类型枚举获取配置信息 Get intelligent dosage page display config data by display type  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_intelligent_bus_config_get_intelligent_deni_display_config_by_type_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int display_type: 展示类型枚举 display type
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[IntelligentDeniConfigInOut], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'display_type'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_intelligent_bus_config_get_intelligent_deni_display_config_by_type_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'display_type' in local_var_params and local_var_params['display_type'] is not None:  # noqa: E501
            query_params.append(('displayType', local_var_params['display_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/IntelligentBusConfig/GetIntelligentDeniDisplayConfigByType', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[IntelligentDeniConfigInOut]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_intelligent_bus_config_update_intelligent_deni_display_configs_post(self, **kwargs):  # noqa: E501
        """更新智能加药展示配置信息 Update intelligent dosage page display config data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_intelligent_bus_config_update_intelligent_deni_display_configs_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[IntelligentDeniConfigInOut] intelligent_deni_config_in_out:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_intelligent_bus_config_update_intelligent_deni_display_configs_post_with_http_info(**kwargs)  # noqa: E501

    def api_intelligent_bus_config_update_intelligent_deni_display_configs_post_with_http_info(self, **kwargs):  # noqa: E501
        """更新智能加药展示配置信息 Update intelligent dosage page display config data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_intelligent_bus_config_update_intelligent_deni_display_configs_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[IntelligentDeniConfigInOut] intelligent_deni_config_in_out:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'intelligent_deni_config_in_out'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_intelligent_bus_config_update_intelligent_deni_display_configs_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'intelligent_deni_config_in_out' in local_var_params:
            body_params = local_var_params['intelligent_deni_config_in_out']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/IntelligentBusConfig/UpdateIntelligentDeniDisplayConfigs', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)
